.. image:: https://img.shields.io/pypi/v/recapturedocs.svg
   :target: `PyPI link`_

.. image:: https://img.shields.io/pypi/pyversions/recapturedocs.svg
   :target: `PyPI link`_

.. _PyPI link: https://pypi.org/project/recapturedocs

.. image:: https://github.com/jaraco/recapturedocs/workflows/tests/badge.svg
   :target: https://github.com/jaraco/recapturedocs/actions?query=workflow%3A%22tests%22
   :alt: tests

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Code style: Black

.. .. image:: https://readthedocs.org/projects/skeleton/badge/?version=latest
..    :target: https://skeleton.readthedocs.io/en/latest/?badge=latest

.. image:: https://img.shields.io/badge/skeleton-2022-informational
   :target: https://blog.jaraco.com/skeleton
